@@ -8,7 +8,7 @@
 #' coefficients of a regression; augment, which adds columns to the original
 #' data such as predictions, residuals and cluster assignments; and glance,
 #' which provides a one-row summary of model-level statistics.
-#' 
+#'
 #' @keywords internal
 "_PACKAGE"
 
@@ -21,9 +21,17 @@
 #' @importFrom tibble tibble as_tibble
 #' @importFrom tidyr pivot_longer pivot_wider
 #'
+#' @import rlang
+#'
 #' @importFrom utils head
 #' @importFrom glue glue
 #'
 #' @import dplyr
 ## usethis namespace: end
 NULL
+
+# 4.6.0 r-devel triggers a dependency WARNING (#1254)
+# * https://github.com/wch/r-source/commit/81571366824cd02b8a660ae60c52f994b7bd9b7c
+quiet_stats4_warning <- function() {
+  stats4::confint
+}
