@@ -1,4 +1,4 @@
-## ----setup, include = FALSE---------------------------------------------------
+## -----------------------------------------------------------------------------
 knitr::opts_chunk$set(message = FALSE, warning = FALSE)
 
 if (rlang::is_installed("ggplot2")) {
@@ -33,9 +33,9 @@ cor(Orange$age, Orange$circumference)
 ggplot(Orange, aes(age, circumference, color = Tree)) +
   geom_line()
 
-## ----message = FALSE, warning = FALSE-----------------------------------------
-Orange %>%
-  group_by(Tree) %>%
+## -----------------------------------------------------------------------------
+Orange |>
+  group_by(Tree) |>
   summarize(correlation = cor(age, circumference))
 
 ## -----------------------------------------------------------------------------
@@ -46,27 +46,27 @@ ct
 tidy(ct)
 
 ## -----------------------------------------------------------------------------
-nested <- Orange %>%
+nested <- Orange |>
   nest(data = -Tree)
 
 ## -----------------------------------------------------------------------------
-nested %>%
+nested |>
   mutate(test = map(data, ~ cor.test(.x$age, .x$circumference)))
 
 ## -----------------------------------------------------------------------------
-nested %>%
+nested |>
   mutate(
     test = map(data, ~ cor.test(.x$age, .x$circumference)), # S3 list-col
     tidied = map(test, tidy)
   )
 
 ## -----------------------------------------------------------------------------
-Orange %>%
-  nest(data = -Tree) %>%
+Orange |>
+  nest(data = -Tree) |>
   mutate(
     test = map(data, ~ cor.test(.x$age, .x$circumference)), # S3 list-col
     tidied = map(test, tidy)
-  ) %>%
+  ) |>
   unnest(tidied)
 
 ## -----------------------------------------------------------------------------
@@ -77,12 +77,12 @@ summary(lm_fit)
 tidy(lm_fit)
 
 ## -----------------------------------------------------------------------------
-Orange %>%
-  nest(data = -Tree) %>%
+Orange |>
+  nest(data = -Tree) |>
   mutate(
     fit = map(data, ~ lm(age ~ circumference, data = .x)),
     tidied = map(fit, tidy)
-  ) %>%
+  ) |>
   unnest(tidied)
 
 ## -----------------------------------------------------------------------------
@@ -90,17 +90,17 @@ data(mtcars)
 mtcars <- as_tibble(mtcars) # to play nicely with list-cols
 mtcars
 
-mtcars %>%
-  nest(data = -am) %>%
+mtcars |>
+  nest(data = -am) |>
   mutate(
     fit = map(data, ~ lm(wt ~ mpg + qsec + gear, data = .x)), # S3 list-col
     tidied = map(fit, tidy)
-  ) %>%
+  ) |>
   unnest(tidied)
 
 ## -----------------------------------------------------------------------------
-regressions <- mtcars %>%
-  nest(data = -am) %>%
+regressions <- mtcars |>
+  nest(data = -am) |>
   mutate(
     fit = map(data, ~ lm(wt ~ mpg + qsec + gear, data = .x)),
     tidied = map(fit, tidy),
@@ -108,12 +108,12 @@ regressions <- mtcars %>%
     augmented = map(fit, augment)
   )
 
-regressions %>%
+regressions |>
   unnest(tidied)
 
-regressions %>%
+regressions |>
   unnest(glanced)
 
-regressions %>%
+regressions |>
   unnest(augmented)
 
