@@ -1,12 +1,10 @@
-context("cmprsk")
-
 skip_on_cran()
 
 skip_if_not_installed("modeltests")
 library(modeltests)
 
 skip_if_not_installed("cmprsk")
-library(cmprsk)
+suppressPackageStartupMessages(library(cmprsk))
 set.seed(2)
 
 # simulate data
@@ -38,16 +36,18 @@ test_that("tidy.cmprsk", {
 
   # check the `conf.level=` argument matches the result in `summary(conf.int=)`
   expect_equal(
-    summary(fit, conf.int = 0.99)$conf.int %>%
-      log() %>%
-      unname() %>%
-      as.data.frame() %>%
-      dplyr::select(., tail(names(.), 2)) %>%
-      unclass() %>%
-      unname(),
-    td3 %>%
-      dplyr::select(conf.low, conf.high) %>%
-      unclass() %>%
-      unname(),
+    {
+      res <- summary(fit, conf.int = 0.99)$conf.int |>
+        log() |>
+        unname() |>
+        as.data.frame()
+      dplyr::select(res, tail(names(res), 2)) |>
+        unclass() |>
+        unname()
+    },
+    td3 |>
+      dplyr::select(conf.low, conf.high) |>
+      unclass() |>
+      unname()
   )
 })
