@@ -1,5 +1,3 @@
-context("fixest")
-
 skip_on_cran()
 
 skip_if_not_installed("modeltests")
@@ -130,10 +128,11 @@ test_that("all other fixest estimators run", {
     strict = FALSE
   )
 
-  augment_error <- "augment is only supported for fixest models estimated with feols, feglm, or femlm"
-  expect_error(augment(res_fenegbin, df), augment_error)
-  expect_error(augment(res_feNmlm, df), augment_error)
-  expect_error(augment(res_fepois, df), augment_error)
+  expect_snapshot(error = TRUE, augment(res_fenegbin))
+
+  expect_snapshot(error = TRUE, augment(res_fenegbin, df))
+  expect_snapshot(error = TRUE, augment(res_feNmlm, df))
+  expect_snapshot(error = TRUE, augment(res_fepois, df))
 })
 
 
@@ -154,7 +153,10 @@ test_that("tidiers work with model results or summary of model results", {
 
   # Repeat for feglm
   res_glm <- fixest::feglm(v2 ~ v4 | id, data = df, family = "poisson")
-  res_glm_summ <- summary(fixest::feglm(v2 ~ v4 | id, data = df, family = "poisson"), se = "hetero")
+  res_glm_summ <- summary(
+    fixest::feglm(v2 ~ v4 | id, data = df, family = "poisson"),
+    se = "hetero"
+  )
   expect_equal(tidy(res_glm, se = "hetero"), tidy(res_glm_summ))
   expect_equal(
     as.data.frame(tidy(res_glm, se = "hetero", conf.int = TRUE)),
