@@ -1,12 +1,10 @@
-context("lavaan")
-
 skip_on_cran()
 
 skip_if_not_installed("modeltests")
 library(modeltests)
 
 skip_if_not_installed("lavaan")
-library(lavaan)
+suppressPackageStartupMessages(library(lavaan))
 
 fit <- sem("mpg ~ wt", data = mtcars)
 form <- paste("F =~", paste0("x", 1:9, collapse = " + "))
