@@ -1,4 +1,7 @@
-context("mass-fitdistr")
+skip_on_cran()
+
+skip_if_not_installed("modeltests")
+library(modeltests)
 
 skip_if_not_installed("MASS")
 
