@@ -1,12 +1,10 @@
-context("mass-rlm")
-
 skip_on_cran()
 
 skip_if_not_installed("modeltests")
 library(modeltests)
 
 skip_if_not_installed("MASS")
-library(MASS)
+suppressPackageStartupMessages(library(MASS))
 
 fit <- rlm(stack.loss ~ ., stackloss)
 
