@@ -1,12 +1,10 @@
-context("quantreg-rqs")
-
 skip_on_cran()
 
 skip_if_not_installed("modeltests")
 library(modeltests)
 
 skip_if_not_installed("quantreg")
-library(quantreg)
+suppressPackageStartupMessages(library(quantreg))
 
 airquality <- na.omit(airquality)
 
@@ -30,14 +28,7 @@ test_that("tidy.rqs", {
 })
 
 test_that("glance.rqs", {
-  expect_error(
-    glance(fit),
-    regexp = paste(
-      "`glance` cannot handle objects of class 'rqs',",
-      "i.e. models with more than one tau value. Please",
-      "use a purrr `map`-based workflow with 'rq' models instead."
-    )
-  )
+  expect_snapshot(error = TRUE, glance(fit))
 })
 
 test_that("augment.rqs", {
