@@ -1,16 +1,21 @@
-context("survival-survexp")
+skip_on_cran()
+
+skip_if_not_installed("modeltests")
+library(modeltests)
 
 skip_if_not_installed("survival")
-library(survival)
+suppressPackageStartupMessages(library(survival))
 
 fit <- suppressWarnings(
   survexp(
     futime ~ 1,
     rmap = list(
-      sex = "male", year = accept.dt,
+      sex = "male",
+      year = accept.dt,
       age = accept.dt - birth.dt
     ),
-    method = "conditional", data = jasa
+    method = "conditional",
+    data = jasa
   )
 )
 
@@ -28,4 +33,3 @@ test_that("glance.survexp", {
   gl <- glance(fit)
   check_glance_outputs(gl)
 })
-
